pub struct ParametricBreakpoint {
pub lambda: f64,
pub source_set: Vec<usize>,
}Expand description
A lambda value at which the optimal minimal min-cut source side changes.
Fields
lambda: f64Parameter value of the transition.
source_set: Vec<usize>Minimal source side that is optimal immediately above this breakpoint (until the next breakpoint), sorted ascending.