Module separation

Module separation 

Graph separators.

Balanced vertex separators for (planar) graphs: removing a small separator set splits the graph into two balanced parts with no edges between them.

Re-exports

pub use planar_separator::PlanarSeparator;
pub use planar_separator::SeparatorResult;

Modules

planar_separator
Lipton-Tarjan style planar separator (1979).